# Form implementation generated from reading ui file 'c:\Users\henrychen\Documents\gitlab\metisse\metisse\example\ui\universal_script_gui_sub2.ui'
#
# Created by: PyQt6 UI code generator 6.1.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.

from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):

    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(463, 351)
        self.stop_Button = QtWidgets.QPushButton(Dialog)
        self.stop_Button.setGeometry(QtCore.QRect(150, 290, 171, 41))
        self.stop_Button.setObjectName("stop_Button")
        self.info_label = QtWidgets.QLabel(Dialog)
        self.info_label.setGeometry(QtCore.QRect(40, 20, 281, 111))
        self.info_label.setObjectName("info_label")
        self.size_listWidget = QtWidgets.QListWidget(Dialog)
        self.size_listWidget.setGeometry(QtCore.QRect(30, 140, 91, 81))
        self.size_listWidget.setObjectName("size_listWidget")
        self.adb_kill_button = QtWidgets.QPushButton(Dialog)
        self.adb_kill_button.setGeometry(QtCore.QRect(240, 230, 201, 41))
        self.adb_kill_button.setObjectName("adb_kill_button")
        self.adjust_button = QtWidgets.QPushButton(Dialog)
        self.adjust_button.setGeometry(QtCore.QRect(120, 140, 111, 41))
        self.adjust_button.setObjectName("adjust_button")
        self.reset_button = QtWidgets.QPushButton(Dialog)
        self.reset_button.setGeometry(QtCore.QRect(120, 180, 111, 41))
        self.reset_button.setObjectName("reset_button")
        self.adb_button = QtWidgets.QPushButton(Dialog)
        self.adb_button.setGeometry(QtCore.QRect(30, 230, 201, 41))
        self.adb_button.setObjectName("adb_button")
        self.dpi_listWidget = QtWidgets.QListWidget(Dialog)
        self.dpi_listWidget.setGeometry(QtCore.QRect(240, 140, 91, 81))
        self.dpi_listWidget.setObjectName("dpi_listWidget")
        self.dpi_adjust_button = QtWidgets.QPushButton(Dialog)
        self.dpi_adjust_button.setGeometry(QtCore.QRect(330, 140, 111, 41))
        self.dpi_adjust_button.setObjectName("dpi_adjust_button")
        self.dpi_reset_button = QtWidgets.QPushButton(Dialog)
        self.dpi_reset_button.setGeometry(QtCore.QRect(330, 180, 111, 41))
        self.dpi_reset_button.setObjectName("dpi_reset_button")
        self.get_device_info_Button = QtWidgets.QPushButton(Dialog)
        self.get_device_info_Button.setGeometry(QtCore.QRect(330, 30, 111, 81))
        self.get_device_info_Button.setObjectName("get_device_info_Button")

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.stop_Button.setText(_translate("Dialog", "關閉"))
        self.info_label.setText(_translate("Dialog", "TextLabel"))
        self.adb_kill_button.setText(_translate("Dialog", "adb kill"))
        self.adjust_button.setText(_translate("Dialog", "調整解析度"))
        self.reset_button.setText(_translate("Dialog", "回復解析度"))
        self.adb_button.setText(_translate("Dialog", "adb connect"))
        self.dpi_adjust_button.setText(_translate("Dialog", "調整dpi"))
        self.dpi_reset_button.setText(_translate("Dialog", "回復dpi"))
        self.get_device_info_Button.setText(_translate("Dialog", "獲取當前裝置\n"
                                                       "螢幕解析度\n"
                                                       "dpi"))
