# Form implementation generated from reading ui file 'c:\Users\henrychen\Documents\gitlab\metisse\metisse\example\ui\universal_script_gui_main.ui'
#
# Created by: PyQt6 UI code generator 6.1.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.

from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):

    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(458, 623)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.script_listWidget = QtWidgets.QListWidget(self.centralwidget)
        self.script_listWidget.setGeometry(QtCore.QRect(50, 140, 181, 281))
        self.script_listWidget.setObjectName("script_listWidget")
        self.lang_listWidget = QtWidgets.QListWidget(self.centralwidget)
        self.lang_listWidget.setGeometry(QtCore.QRect(230, 140, 51, 281))
        self.lang_listWidget.setObjectName("lang_listWidget")
        self.device_listWidget = QtWidgets.QListWidget(self.centralwidget)
        self.device_listWidget.setGeometry(QtCore.QRect(280, 140, 131, 281))
        self.device_listWidget.setObjectName("device_listWidget")
        self.excute_button = QtWidgets.QPushButton(self.centralwidget)
        self.excute_button.setGeometry(QtCore.QRect(50, 420, 231, 81))
        self.excute_button.setObjectName("excute_button")
        self.renew_button = QtWidgets.QPushButton(self.centralwidget)
        self.renew_button.setGeometry(QtCore.QRect(280, 420, 131, 81))
        self.renew_button.setObjectName("renew_button")
        self.text_label_show_info = QtWidgets.QLabel(self.centralwidget)
        self.text_label_show_info.setGeometry(QtCore.QRect(50, 10, 361, 101))
        self.text_label_show_info.setObjectName("text_label_show_info")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setGeometry(QtCore.QRect(110, 120, 51, 20))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        self.label_3.setGeometry(QtCore.QRect(240, 120, 31, 20))
        self.label_3.setObjectName("label_3")
        self.label_4 = QtWidgets.QLabel(self.centralwidget)
        self.label_4.setGeometry(QtCore.QRect(330, 120, 31, 20))
        self.label_4.setObjectName("label_4")
        self.sub2_button = QtWidgets.QPushButton(self.centralwidget)
        self.sub2_button.setGeometry(QtCore.QRect(280, 500, 131, 81))
        self.sub2_button.setObjectName("sub2_button")
        self.sub3_button = QtWidgets.QPushButton(self.centralwidget)
        self.sub3_button.setGeometry(QtCore.QRect(50, 500, 231, 81))
        self.sub3_button.setObjectName("sub3_button")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 458, 22))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.excute_button.setText(_translate("MainWindow", "執行選擇腳本"))
        self.renew_button.setText(_translate("MainWindow", "刷新裝置清單"))
        self.text_label_show_info.setText(_translate("MainWindow", "test"))
        self.label_2.setText(_translate("MainWindow", "選擇腳本"))
        self.label_3.setText(_translate("MainWindow", "語系"))
        self.label_4.setText(_translate("MainWindow", "裝置"))
        self.sub2_button.setText(_translate("MainWindow", "調整android裝置"))
        self.sub3_button.setText(_translate("MainWindow", "選擇腳本說明(起始位置)"))
