class Settings(object):
    DEV_ENVIRONMENT_ROOT_PATH = ['icon', 'ui']  #,'script'
    SCRIPT_ENVIRONMENT_ROOT_PATH = ['temp_image', 'storage', 'backup', 'log']
    OS_ENVIRONMENT = ['android', 'ios']
