class UiSettings(object):
    DEVICE_SCREEN_SIZE = ['1280x720', '720x1280']  #'1488x2266', '1280x720',
    DEVICE_SCREEN_DENSITY = ['160']  # '240'
    LOAD_MAIN_UI = 'universal_script_gui_main.ui'
    LOAD_SUB_UI = ['universal_script_gui_sub.ui','universal_script_gui_sub2.ui','universal_script_gui_sub3.ui']